@@ -59,14 +59,14 @@ except ImportError:  # pragma: nocover
 @click.option(
     "--agent",
     "package_type",
-    help="Provide a local alias for the agent.",
+    help="Specify the package type as agent.",
     default=True,
     flag_value=AGENT,
 )
 @click.option(
     "--service",
     "package_type",
-    help="Provide a local alias for the agent.",
+    help="Specify the package type as service.",
     flag_value=SERVICE,
 )
 @click.argument("public-id", type=PublicIdParameter(), required=True)
