@@ -2,6 +2,7 @@
 # ------------------------------------------------------------------------------
 #
 #   Copyright 2021-2022 Valory AG
+#   Copyright 2018-2021 Fetch.AI Limited
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -16,25 +17,26 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
 """Tests for valory/http_client connection. Adapted from original AEA code."""
-
 # pylint: skip-file
 
 import asyncio
 import logging
-import socket
 from asyncio import CancelledError
 from typing import Any, cast
 from unittest.mock import MagicMock, Mock, patch
 
 import aiohttp
 import pytest
+
 from aea.common import Address
-from aea.configurations.base import ConnectionConfig, PublicId
+from aea.configurations.base import ConnectionConfig
 from aea.identity.base import Identity
 from aea.mail.base import Envelope, Message
 from aea.protocols.dialogue.base import Dialogue as BaseDialogue
+from aea.test_tools.constants import UNKNOWN_PROTOCOL_PUBLIC_ID
+from aea.test_tools.mocks import AnyStringWith
+from aea.test_tools.network import get_host, get_unused_tcp_port
 
 from packages.valory.connections.http_client.connection import HTTPClientConnection
 from packages.valory.protocols.http.dialogues import HttpDialogue
@@ -42,47 +44,9 @@ from packages.valory.protocols.http.dialogues import HttpDialogues as BaseHttpDi
 from packages.valory.protocols.http.message import HttpMessage
 
 
-UNKNOWN_PROTOCOL_PUBLIC_ID = PublicId("unused", "unused", "1.0.0")
-
 logger = logging.getLogger(__name__)
 
 
-def get_host() -> str:
-    """Get the host."""
-    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    try:
-        # doesn't even have to be reachable
-        s.connect(("10.255.255.255", 1))
-        IP = s.getsockname()[0]
-    except Exception:
-        IP = "127.0.0.1"
-    finally:
-        s.close()
-    return IP
-
-
-def get_unused_tcp_port() -> int:
-    """Get an unused TCP port."""
-    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-    s.bind(("127.0.0.1", 0))
-    s.listen(1)
-    port = s.getsockname()[1]
-    s.close()
-    return port
-
-
-class AnyStringWith(str):
-    """
-    Helper class to assert calls of mocked method with string arguments.
-
-    It will use string inclusion as equality comparator.
-    """
-
-    def __eq__(self, other: Any) -> bool:
-        """Check equality."""
-        return self in other
-
-
 class _MockRequest:
     """Fake request for aiohttp client session."""
 
