@@ -40,6 +40,9 @@ from packages.valory.skills.apy_estimation_abci.models import (
 from packages.valory.skills.apy_estimation_abci.models import (
     RandomnessApi as APYEstimationRandomnessApi,
 )
+from packages.valory.skills.apy_estimation_abci.models import (
+    ServerApi as APYEstimationServerApi,
+)
 from packages.valory.skills.apy_estimation_abci.models import (
     SpookySwapSubgraph as APYEstimationSpookySwapSubgraph,
 )
@@ -59,6 +62,7 @@ FantomSubgraph = APYEstimationFantomSubgraph
 ETHSubgraph = APYEstimationETHSubgraph
 UniswapSubgraph = APYEstimationUniswapSubgraph
 SpookySwapSubgraph = APYEstimationSpookySwapSubgraph
+ServerApi = APYEstimationServerApi
 APYParams = APYEstimationAPYParams
 
 MARGIN = 5
