@@ -49,10 +49,16 @@ def main() -> None:  # pylint: disable=too-many-locals
 
     broken_links: List[Tuple[str, Any, Any]] = []
     http_links = []
-    http_skips = ["http://www.fipa.org/repository/ips.php3"]
+    http_skips = [
+        "http://www.fipa.org/repository/ips.php3",
+        "http://host.docker.internal:8545```",
+        "http://host.docker.internal:8545",
+    ]
     url_skips = [
         "https://github.com/valory-xyz/open-autonomy/trunk/packages",
         "https://github.com/valory-xyz/open-autonomy/trunk/infrastructure",
+        "https://gateway.autonolas.tech/ipfs/`<hash>`,",
+        "https://gateway.autonolas.tech/ipfs/Qmbh9SQLbNRawh9Km3PMEDSxo77k1wib8fYZUdZkhPBiev",
     ]
 
     # Configure request retries
